package gatewayapi.sample.iaszone;

import java.util.function.BiConsumer;

import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import com.mmbnetworks.gatewayapi.entity.Device;
import com.mmbnetworks.gatewayapi.entity.Property;
import com.mmbnetworks.rapidconnectdevice.zcl.cluster.IASZone.ZoneStatus;
import com.mmbnetworks.rotarrandevicemodel.zigbee.property.ZoneStatusProperty;

public class SamplePropertyHandler implements BiConsumer<Device, Property> {
    
    private final JsonParser jsonParser;

    public SamplePropertyHandler() {
        this.jsonParser = new JsonParser();
    }

    @Override
    public void accept(Device device, Property property) {
        // This method gets called whenever a Property on a device changes.
        // By default, client callbacks are called from a single thread managed by GAPI.
        // Therefore, avoid writing blocking code in this method, or other client callbacks
        // (such as DeviceEventHandlers, or ProtocolHandlers) may be blocked.
        
        System.out.println("Property update triggered for device: " + device.getID());
        System.out.println("Property: " + property.getName() + ", value: " + property.getValue() + ", type: " + property.getType());
        
        // Example of how to deal with json properties from the device; in this case,
        // reading the value of alarm1 of the zoneStatus property.
        if (property.getName().equals(ZoneStatusProperty.NAME)) {
            final JsonObject jsonObject = jsonParser.parse(property.getValue()).getAsJsonObject();
            final String alarm1 = jsonObject.get(ZoneStatus.ALARM1.toString()).getAsString();
            
            if (alarm1.equals(ZoneStatus.ALARM1.getTriggeredValue())) {
                System.out.println("ALARM 1: TRIGGERED!");
            
            } else if (alarm1.equals(ZoneStatus.ALARM1.getNotTriggeredValue())) {
                System.out.println("ALARM 1: closed");
            }
        }
    }

}
